---
title: aws_s3
type: cache
status: stable
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/cache/aws_s3.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Stores each item in an S3 bucket as a file, where an item ID is the path of the item within the bucket.

Introduced in version 3.36.0.


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yml
# Common config fields, showing default values
label: ""
aws_s3:
  bucket: ""
  content_type: application/octet-stream
```

</TabItem>
<TabItem value="advanced">

```yml
# All config fields, showing default values
label: ""
aws_s3:
  bucket: ""
  content_type: application/octet-stream
  force_path_style_urls: false
  retries:
    initial_interval: 1s
    max_interval: 5s
    max_elapsed_time: 30s
  region: ""
  endpoint: ""
  credentials:
    profile: ""
    id: ""
    secret: ""
    token: ""
    role: ""
    role_external_id: ""
```

</TabItem>
</Tabs>

It is not possible to atomically upload S3 objects exclusively when the target does not already exist, therefore this cache is not suitable for deduplication.

## Fields

### `bucket`

The S3 bucket to store items in.


Type: `string`  

### `content_type`

The content type to set for each item.


Type: `string`  
Default: `"application/octet-stream"`  

### `force_path_style_urls`

Forces the client API to use path style URLs, which helps when connecting to custom endpoints.


Type: `bool`  
Default: `false`  

### `retries`

Determine time intervals and cut offs for retry attempts.


Type: `object`  

### `retries.initial_interval`

The initial period to wait between retry attempts.


Type: `string`  
Default: `"1s"`  

```yml
# Examples

initial_interval: 50ms

initial_interval: 1s
```

### `retries.max_interval`

The maximum period to wait between retry attempts


Type: `string`  
Default: `"5s"`  

```yml
# Examples

max_interval: 5s

max_interval: 1m
```

### `retries.max_elapsed_time`

The maximum overall period of time to spend on retry attempts before the request is aborted.


Type: `string`  
Default: `"30s"`  

```yml
# Examples

max_elapsed_time: 1m

max_elapsed_time: 1h
```

### `region`

The AWS region to target.


Type: `string`  
Default: `""`  

### `endpoint`

Allows you to specify a custom endpoint for the AWS API.


Type: `string`  
Default: `""`  

### `credentials`

Optional manual configuration of AWS credentials to use. More information can be found [in this document](/docs/guides/cloud/aws).


Type: `object`  

### `credentials.profile`

A profile from `~/.aws/credentials` to use.


Type: `string`  
Default: `""`  

### `credentials.id`

The ID of credentials to use.


Type: `string`  
Default: `""`  

### `credentials.secret`

The secret for the credentials being used.


Type: `string`  
Default: `""`  

### `credentials.token`

The token for the credentials being used, required when using short term credentials.


Type: `string`  
Default: `""`  

### `credentials.role`

A role ARN to assume.


Type: `string`  
Default: `""`  

### `credentials.role_external_id`

An external ID to provide when assuming a role.


Type: `string`  
Default: `""`  


